#' Length of Left Middle Finger and Height for an SRS of Size 200 
#' 
#' Length of left middle finger and height for an SRS of 200 
#' criminals from the anthrop dataset
#' @name anthsrs
#' @docType data
#' @format Data frame with the following 2 variables: 
#' \describe{
#'   \item{finger}{length of left middle finger (cm)}
#'   \item{height}{height (inches)}
#' }
#' @source Macdonell, W. R. (1901). On criminal anthropometry and the
#' identification of criminals, \emph{Biometrika}, 1: 177--227.
#' @references Lohr (1999). Sampling: Design and Analysis, Duxbury, p. TODO and
#'   438.
"anthsrs"